@@ -173,7 +173,8 @@ setMethod("plot", signature(x = "IC", y = "missing"),
         w0 <- getOption("warn")
         options(warn = -1)
         on.exit(options(warn = w0))
-        opar <- par()
+        opar <- par(no.readonly = TRUE)
+#        opar$cin <- opar$cra <- opar$csi <- opar$cxy <-  opar$din <- NULL
         on.exit(par(opar))
         if (!withSweave)
              devNew()
