@@ -33,8 +33,17 @@ setMethod("qqplot", signature(x = "ANY",
        r <- radius(neighbor(y))
        n <- floor((1-r)*n)
     }
+    if(is.null(mcl$alpha.CI))
+       mcl$alpha.CI <- .95
+    cor <- radius(neighbor(y))
+    mcl$legend.alpha <- eval(mcl$alpha.CI)
+    mcl$alpha.CI <- min(eval(mcl$alpha.CI)+cor,1)
+
+
     mcl$n <- n
     mcl$y <- y@center
+    mcl$legend.pref <- paste(mcl$legend.pref,"outlier-adjusted",sep="")
+
 
     xD <- fct(distance)(x)
     x.cex <- 3/(1+log(1+xD))
@@ -58,6 +67,14 @@ setMethod("qqplot", signature(x = "ANY", y = "InfRobModel"),
     mcl <- as.list(mc)[-1]
     if(is.null(mcl$distance)) distance <- NormType()
 
+    if(is.null(mcl$alpha.CI))
+       mcl$alpha.CI <- .95
+    cor <- radius(neighbor(y))/sqrt(n)
+    mcl$legend.alpha <- eval(mcl$alpha.CI)
+    mcl$alpha.CI <- min(eval(mcl$alpha.CI)+cor,1)
+
+
+
     if(is.null(mcl$n.CI)) mcl$n.CI <- n
     if(n.adj){
        r <- radius(neighbor(y))
@@ -65,7 +82,8 @@ setMethod("qqplot", signature(x = "ANY", y = "InfRobModel"),
     }
     mcl$n <- n
     mcl$y <- y@center
-
+    mcl$legend.pref <- paste(mcl$legend.pref,"outlier-adjusted",sep="")
+    
     FI <- PosSemDefSymmMatrix(FisherInfo(y@center))
     L2D <- as(diag(nrow(FI)) %*% L2deriv(y@center), "EuclRandVariable")
     L2Dx <- evalRandVar(L2D,matrix(x))[,,1]
